Changelog
=========


1.0a4 (2020-06-12)
------------------

- render img tag manually, to avoid having width and height attributes set
  [MrTango]


1.0a3 (2020-06-12)
------------------

- Fix flexbin image height
  [MrTango]

- Fix title and description in spotlight view
  [MrTango]


1.0a2 (2020-06-11)
------------------

- Fix resources files in released package
  [MrTango]

- Support also Collections not only Folders
  [MrTango]


1.0a1 (2020-06-11)
------------------

- Initial release.
  [MrTango]
